@@ -114,6 +114,10 @@ class ScrollArea(Base):
     :param area_width: Width of scrollable area in px
     :param area_height: Height of scrollable area in px
     :param area_color: Background color, it can be a color or an image
+    :param controls_joystick: Use joystick events
+    :param controls_keyboard: Use keyboard events
+    :param controls_mouse: Use mouse events
+    :param controls_touchscreen: Use touchscreen events
     :param extend_x: Px to extend the surface on x axis in px from left. Recommended use only within Menus
     :param extend_y: Px to extend the surface on y axis in px from top. Recommended use only within Menus
     :param menubar: Menubar for style compatibility. ``None`` if ScrollArea is not used within a Menu (for example, in Frames)
@@ -153,6 +157,10 @@ class ScrollArea(Base):
             area_width: int,
             area_height: int,
             area_color: Optional[Union[ColorInputType, 'pygame_menu.BaseImage']] = None,
+            controls_joystick: bool = True,
+            controls_keyboard: bool = True,
+            controls_mouse: bool = True,
+            controls_touchscreen: bool = True,
             extend_x: int = 0,
             extend_y: int = 0,
             menubar: Optional['pygame_menu.widgets.MenuBar'] = None,
@@ -175,6 +183,10 @@ class ScrollArea(Base):
 
         assert isinstance(area_height, int)
         assert isinstance(area_width, int)
+        assert isinstance(controls_joystick, bool)
+        assert isinstance(controls_keyboard, bool)
+        assert isinstance(controls_mouse, bool)
+        assert isinstance(controls_touchscreen, bool)
         assert isinstance(extend_x, int)
         assert isinstance(extend_y, int)
         assert isinstance(scrollbar_slider_pad, NumberInstance)
@@ -237,6 +249,7 @@ class ScrollArea(Base):
                     slider_pad=scrollbar_slider_pad,
                     values_range=(0, max(1, self.get_hidden_height()))
                 )
+
             else:
                 sbar = ScrollBar(
                     length=self._view_rect.width,
@@ -248,13 +261,19 @@ class ScrollArea(Base):
                     slider_pad=scrollbar_slider_pad,
                     values_range=(0, max(1, self.get_hidden_width()))
                 )
+
             sbar.set_shadow(
                 enabled=shadow,
                 color=shadow_color,
                 position=shadow_position,
                 offset=shadow_offset
             )
-            sbar.set_controls(joystick=False)
+            sbar.set_controls(
+                joystick=controls_joystick,
+                mouse=controls_mouse,
+                touchscreen=controls_touchscreen,
+                keyboard=controls_keyboard
+            )
             sbar.set_cursor(cursor=scrollbar_cursor)
             sbar.set_scrollarea(self)
             sbar.configured = True
@@ -538,8 +557,6 @@ class ScrollArea(Base):
         elif orientation == ORIENTATION_VERTICAL:
             return int(self._rect.width - self._view_rect.width)
 
-        return 0
-
     def get_world_rect(self, absolute: bool = False) -> 'pygame.Rect':
         """
         Return the world rect.
@@ -909,6 +926,18 @@ class ScrollArea(Base):
         self._apply_size_changes()
         return self
 
+    def get_world(self) -> Optional['pygame.Surface']:
+        """
+        Return the world surface area.
+
+        .. warning::
+
+            Use with caution.
+
+        :return: World surface. ``None`` if it has not been set yet
+        """
+        return self._world
+
     def get_parent_position(self) -> Tuple2IntType:
         """
         Return parent ScrollArea position.
@@ -963,23 +992,6 @@ class ScrollArea(Base):
                     parent = parent._parent_scrollarea
         return view_rect_absolute
 
-    # def get_real_view_rect(self, visible: bool = False) -> 'pygame.Rect':
-    #     """
-    #     Return the ScrollArea real position view rect clipped if it is not visible by
-    #     it's parent ScrollArea.
-    #
-    #     :return: Clipped real position view rect
-    #     """
-    #     view_rect_real = self.to_real_position(self._view_rect, visible=visible)
-    #     if self._parent_scrollarea is not None:
-    #         parent = self._parent_scrollarea
-    #         while True:  # Recursive
-    #             if parent is None:
-    #                 break
-    #             view_rect_real = parent.get_real_view_rect(visible=visible).clip(view_rect_real)
-    #             parent = parent._parent_scrollarea
-    #     return view_rect_real
-
     def to_real_position(self, virtual: Union['pygame.Rect', Tuple2NumberType], visible: bool = False
                          ) -> Union['pygame.Rect', Tuple2IntType]:
         """
