@@ -47,6 +47,10 @@ from pygame_menu.widgets.widget.colorinput import COLORINPUT_TYPE_RGB, \
     COLORINPUT_TYPE_HEX, COLORINPUT_HEX_FORMAT_UPPER, COLORINPUT_HEX_FORMAT_NONE, \
     COLORINPUT_HEX_FORMAT_LOWER
 
+from pygame_menu.widgets.widget.dropselect_multiple import \
+    DROPSELECT_MULTIPLE_SFORMAT_TOTAL, DROPSELECT_MULTIPLE_SFORMAT_LIST_COMMA, \
+    DROPSELECT_MULTIPLE_SFORMAT_LIST_HYPHEN
+
 from pygame_menu.widgets.widget.frame import FRAME_DEFAULT_TITLE_BACKGROUND_COLOR, \
     FRAME_TITLE_BUTTON_CLOSE, FRAME_TITLE_BUTTON_MAXIMIZE, FRAME_TITLE_BUTTON_MINIMIZE
 
