@@ -39,9 +39,10 @@ import pygame_menu
 import pygame_menu.controls as ctrl
 
 from pygame_menu.font import FontType, get_font, assert_font
-from pygame_menu.locals import ORIENTATION_VERTICAL, FINGERDOWN, FINGERUP
+from pygame_menu.locals import ORIENTATION_VERTICAL, FINGERDOWN, FINGERUP, \
+    POSITION_NORTHWEST, POSITION_SOUTHEAST
 from pygame_menu.utils import check_key_pressed_valid, assert_color, assert_vector, \
-    make_surface, parse_padding, get_finger_pos, uuid4, assert_cursor
+    make_surface, parse_padding, get_finger_pos, uuid4, assert_cursor, assert_position
 from pygame_menu.widgets.core import Widget
 from pygame_menu.widgets.widget.button import Button
 from pygame_menu.widgets.widget.frame import Frame
@@ -50,7 +51,7 @@ from pygame_menu.widgets.widget.selector import check_selector_items
 from pygame_menu._types import Tuple, Union, List, Any, Optional, CallbackType, \
     ColorType, Dict, ColorInputType, Tuple2IntType, Tuple3IntType, PaddingType, \
     PaddingInstance, Tuple4IntType, NumberType, EventVectorType, Tuple2NumberType, \
-    CursorInputType, CursorType
+    CursorInputType, CursorType, NumberInstance
 
 
 # noinspection PyMissingOrEmptyDocstring,PyProtectedMember
@@ -79,7 +80,7 @@ class DropSelect(Widget):
 
     .. note::
 
-        DropSelect only implements translation.
+        DropSelect only accepts translation transformation.
 
     :param title: Drop select title
     :param items: Items of the drop select
@@ -91,6 +92,17 @@ class DropSelect(Widget):
     :param open_middle: If ``True`` the selection box is opened in the middle of the menu
     :param placeholder: Text shown if no option is selected yet
     :param placeholder_add_to_selection_box: If ``True`` adds the placeholder button to the selection box
+    :param scrollbar_color: Scrollbar color
+    :param scrollbar_cursor: Cursor of the scrollbars if mouse is placed over. By default is ``None``
+    :param scrollbar_shadow: Indicate if a shadow is drawn on each scrollbar
+    :param scrollbar_shadow_color: Color of the shadow of each scrollbar
+    :param scrollbar_shadow_offset: Offset of the scrollbar shadow in px
+    :param scrollbar_shadow_position: Position of the scrollbar shadow. See :py:mod:`pygame_menu.locals`
+    :param scrollbar_slider_color: Color of the sliders
+    :param scrollbar_slider_hover_color: Color of the slider if hovered or clicked
+    :param scrollbar_slider_pad: Space between slider and scrollbars borders in px
+    :param scrollbar_thick: Scrollbar thickness in px
+    :param scrollbars: Scrollbar position. See :py:mod:`pygame_menu.locals`
     :param selection_box_arrow_color: Selection box arrow color
     :param selection_box_arrow_margin: Selection box arrow margin (left, right, vertical) in px
     :param selection_box_bgcolor: Selection box background color
@@ -124,6 +136,17 @@ class DropSelect(Widget):
     _option_font: Optional['pygame.font.Font']
     _placeholder: str
     _placeholder_add_to_selection_box: bool
+    _scrollbar_color: ColorType
+    _scrollbar_cursor: CursorType
+    _scrollbar_shadow: bool
+    _scrollbar_shadow_color: ColorType
+    _scrollbar_shadow_offset: int
+    _scrollbar_shadow_position: str
+    _scrollbar_slider_color: ColorType
+    _scrollbar_slider_hover_color: ColorType
+    _scrollbar_slider_pad: NumberType
+    _scrollbar_thick: int
+    _scrollbars: str
     _selection_box_arrow_color: ColorType
     _selection_box_arrow_margin: Tuple3IntType
     _selection_box_bgcolor: ColorType
@@ -144,7 +167,6 @@ class DropSelect(Widget):
     _selection_option_left_space_margin: Tuple3IntType
     _selection_option_padding: Tuple4IntType
     _selection_option_selected_bgcolor: ColorType
-    _theme: Optional['pygame_menu.Theme']
     _title_size: Tuple2IntType
 
     def __init__(
@@ -159,6 +181,17 @@ class DropSelect(Widget):
             open_middle: bool = False,
             placeholder: str = 'Select an option',
             placeholder_add_to_selection_box: bool = True,
+            scrollbar_color: ColorInputType = (235, 235, 235),
+            scrollbar_cursor: CursorInputType = None,
+            scrollbar_shadow: bool = False,
+            scrollbar_shadow_color: ColorInputType = (0, 0, 0),
+            scrollbar_shadow_offset: int = 2,
+            scrollbar_shadow_position: str = POSITION_NORTHWEST,
+            scrollbar_slider_color: ColorInputType = (200, 200, 200),
+            scrollbar_slider_hover_color: ColorInputType = (170, 170, 170),
+            scrollbar_slider_pad: NumberType = 0,
+            scrollbar_thick: int = 20,
+            scrollbars: str = POSITION_SOUTHEAST,
             selection_box_arrow_color: ColorInputType = (150, 150, 150),
             selection_box_arrow_margin: Tuple3IntType = (5, 5, 0),
             selection_box_bgcolor: ColorInputType = (255, 255, 255),
@@ -199,6 +232,10 @@ class DropSelect(Widget):
         assert isinstance(default, int), 'default must be an integer'
 
         # Check styling
+        assert isinstance(scrollbar_shadow, bool)
+        assert isinstance(scrollbar_shadow_offset, int) and scrollbar_shadow_offset >= 0
+        assert isinstance(scrollbar_slider_pad, NumberInstance) and scrollbar_slider_pad >= 0
+        assert isinstance(scrollbar_thick, int) and scrollbar_thick >= 0
         assert isinstance(selection_box_border_width, int) and selection_box_border_width >= 0
         assert isinstance(selection_box_height, int) and selection_box_height >= 1
         assert isinstance(selection_box_text_margin, int) and selection_box_text_margin >= 0
@@ -206,10 +243,17 @@ class DropSelect(Widget):
         assert isinstance(selection_infinite, bool)
         assert isinstance(selection_option_border_width, int) and selection_option_border_width >= 0
         assert isinstance(selection_option_padding, PaddingInstance)
+        assert_cursor(scrollbar_cursor)
         assert_cursor(selection_option_cursor)
+        assert_position(scrollbar_shadow_position)
+        assert_position(scrollbars)
         assert_vector(selection_box_arrow_margin, 3, int)
         assert_vector(selection_box_inflate, 2, int)
         assert_vector(selection_box_margin, 2)
+        scrollbar_color = assert_color(scrollbar_color)
+        scrollbar_shadow_color = assert_color(scrollbar_shadow_color)
+        scrollbar_slider_color = assert_color(scrollbar_slider_color)
+        scrollbar_slider_hover_color = assert_color(scrollbar_slider_hover_color)
         selection_box_arrow_color = assert_color(selection_box_arrow_color)
         selection_box_bgcolor = assert_color(selection_box_bgcolor)
         selection_box_border_color = assert_color(selection_box_border_color)
@@ -233,6 +277,7 @@ class DropSelect(Widget):
             kwargs=kwargs
         )
 
+        self._accept_events = True
         self._close_on_apply = True
         self._default_value = default
         self._drop_frame = None
@@ -243,7 +288,6 @@ class DropSelect(Widget):
         self._placeholder = placeholder
         self._placeholder_add_to_selection_box = placeholder_add_to_selection_box
         self._selection_effect_draw_post = False
-        self._theme = None
         self._title_size = (0, 0)
 
         # If True adds a space equals to the height of the option at left, used for
@@ -254,6 +298,17 @@ class DropSelect(Widget):
 
         # Style
         self._option_font = None
+        self._scrollbar_color = scrollbar_color
+        self._scrollbar_cursor = scrollbar_cursor
+        self._scrollbar_shadow = scrollbar_shadow
+        self._scrollbar_shadow_color = scrollbar_shadow_color
+        self._scrollbar_shadow_offset = scrollbar_shadow_offset
+        self._scrollbar_shadow_position = scrollbar_shadow_position
+        self._scrollbar_slider_color = scrollbar_slider_color
+        self._scrollbar_slider_hover_color = scrollbar_slider_hover_color
+        self._scrollbar_slider_pad = scrollbar_slider_pad
+        self._scrollbar_thick = scrollbar_thick
+        self._scrollbars = scrollbars
         self._selection_box_arrow_color = selection_box_arrow_color
         self._selection_box_arrow_margin = selection_box_arrow_margin
         self._selection_box_bgcolor = selection_box_bgcolor
@@ -279,19 +334,8 @@ class DropSelect(Widget):
             'size': selection_option_font_size
         }
 
-        # Configure public's
         self.active = False
 
-    def set_theme(self, theme: 'pygame_menu.Theme') -> 'DropSelect':
-        """
-        Set object theme.
-
-        :param theme: Theme
-        :return: Self reference
-        """
-        self._theme = theme
-        return self
-
     def set_default_value(self, index: int) -> 'DropSelect':
         self._default_value = index
         return self
@@ -321,24 +365,11 @@ class DropSelect(Widget):
                                             + h - h / 4
                                             + 2 * self._selection_box_border_width)
 
-    def make_selection_drop(self, **kwargs) -> 'DropSelect':
+    def _make_selection_drop(self) -> 'DropSelect':
         """
-        Make selection drop box.
+        Make the selection drop box. This function creates the box UI and adds
+        the selection options. Should be called after the widget is configured.
 
-        kwargs (Optional)
-            - ``scrollbar_color``               (tuple, list, str, int, :py:class:`pygame.Color`) – Scrollbar color
-            - ``scrollbar_cursor``              (int, :py:class:`pygame.cursors.Cursor`, None) – Cursor of the scrollbars if mouse is placed over. By default is ``None``
-            - ``scrollbar_shadow_color``        (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the shadow of each scrollbar
-            - ``scrollbar_shadow_offset``       (int) – Offset of the scrollbar shadow in px
-            - ``scrollbar_shadow_position``     (str) – Position of the scrollbar shadow. See :py:mod:`pygame_menu.locals`
-            - ``scrollbar_shadow``              (bool) – Indicate if a shadow is drawn on each scrollbar
-            - ``scrollbar_slider_color``        (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the sliders
-            - ``scrollbar_slider_hover_color``  (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the slider if hovered or clicked
-            - ``scrollbar_slider_pad``          (int, float) – Space between slider and scrollbars borders in px
-            - ``scrollbar_thick``               (int) – Scrollbar thickness in px
-            - ``scrollbars``                    (str) – Scrollbar position. See :py:mod:`pygame_menu.locals`
-
-        :param kwargs: Optional keyword arguments
         :return: Self reference
         """
         # noinspection PyUnresolvedReferences
@@ -347,12 +378,6 @@ class DropSelect(Widget):
         if not self.configured:
             raise RuntimeError('{0} must be configured before creating selection drop'
                                ''.format(self.get_class_id()))
-        if self._theme is None:
-            if self._menu is not None:
-                self.set_theme(self._menu.get_theme())
-            else:
-                raise RuntimeError('{0} theme must be defined')
-        scrollbar_thickness = kwargs.get('scrollbar_thick', self._theme.scrollbar_thick)
 
         # Create options buttons
         total_height = 0
@@ -432,8 +457,8 @@ class DropSelect(Widget):
 
         max_width = frame_width
         if total_height != max_height:
-            max_width -= scrollbar_thickness
-            frame_width -= scrollbar_thickness
+            max_width -= self._scrollbar_thick
+            frame_width -= self._scrollbar_thick
             total_height -= self._selection_box_border_width
             max_height -= self._selection_box_border_width
         elif total_height > 0:
@@ -475,47 +500,46 @@ class DropSelect(Widget):
         self._drop_frame.configured = True
         self._drop_frame.set_tab_size(self._tab_size)
         self._drop_frame._update__repr___(self)
+        self._drop_frame.set_controls(
+            joystick=self._joystick_enabled,
+            mouse=self._mouse_enabled,
+            touchscreen=self._touchscreen_enabled,
+            keyboard=self._keyboard_enabled
+        )
 
         if total_height > 0:
-            scrollbar_color = kwargs.get('scrollbar_color',
-                                         self._theme.scrollbar_color)
-            scrollbars = kwargs.get('scrollbars',
-                                    self._theme.scrollarea_position)
-            if not kwargs.get('scrollbars_parsed', False):
-                scrollbars = get_scrollbars_from_position(scrollbars)
+            # Menu is needed while creating the scrollarea, as that reference
+            # is later passed to the scrollbars, which need menu for touchscreen
+            # events
+            self._drop_frame._menu = self._menu
             self._drop_frame.make_scrollarea(
                 max_width=frame_width,
                 max_height=max_height,
                 scrollarea_color=self._selection_box_arrow_color,
-                scrollbar_color=scrollbar_color,
-                scrollbar_cursor=kwargs.get('scrollbar_cursor',
-                                            self._theme.scrollbar_cursor),
-                scrollbar_shadow_color=kwargs.get('scrollbar_shadow_color',
-                                                  self._theme.scrollbar_shadow_color),
-                scrollbar_shadow_offset=kwargs.get('scrollbar_shadow_offset',
-                                                   self._theme.scrollbar_shadow_offset),
-                scrollbar_shadow_position=kwargs.get('scrollbar_shadow_position',
-                                                     self._theme.scrollbar_shadow_position),
-                scrollbar_shadow=kwargs.get('scrollbar_shadow',
-                                            self._theme.scrollbar_shadow),
-                scrollbar_slider_color=kwargs.get('scrollbar_slider_color',
-                                                  self._theme.scrollbar_slider_color),
-                scrollbar_slider_hover_color=kwargs.get('scrollbar_slider_hover_color',
-                                                        self._theme.scrollbar_slider_hover_color),
-                scrollbar_slider_pad=kwargs.get('scrollbar_slider_pad',
-                                                self._theme.scrollbar_slider_pad),
-                scrollbar_thick=scrollbar_thickness,
-                scrollbars=scrollbars
+                scrollbar_color=self._scrollbar_color,
+                scrollbar_cursor=self._scrollbar_cursor,
+                scrollbar_shadow_color=self._scrollbar_shadow_color,
+                scrollbar_shadow_offset=self._scrollbar_shadow_offset,
+                scrollbar_shadow_position=self._scrollbar_shadow_position,
+                scrollbar_shadow=self._scrollbar_shadow,
+                scrollbar_slider_color=self._scrollbar_slider_color,
+                scrollbar_slider_hover_color=self._scrollbar_slider_hover_color,
+                scrollbar_slider_pad=self._scrollbar_slider_pad,
+                scrollbar_thick=self._scrollbar_thick,
+                scrollbars=get_scrollbars_from_position(self._scrollbars)
             )
 
+        # Menu is formerly set in frame. That method adds the frame to update frames
+        # depending if frame is scrollable or not
         self._drop_frame.set_menu(self._menu)
+
         self._drop_frame.set_scrollarea(self._scrollarea)
         if self._frame is not None:
             self._drop_frame.set_frame(self._frame)
 
         # Set sizing properties
         if total_height > 0:
-            add_scrollbar = scrollbar_thickness if max_width != frame_width else 0
+            add_scrollbar = self._scrollbar_thick if max_width != frame_width else 0
             border_w = self._selection_box_border_width if total_height != max_height else 0
             self._drop_frame.set_attribute('height',
                                            max_height + add_scrollbar - border_w)
@@ -541,6 +565,9 @@ class DropSelect(Widget):
 
         return self
 
+    def _append_to_menu(self) -> None:
+        self._make_selection_drop()
+
     def on_remove_from_menu(self) -> 'DropSelect':
         if self._drop_frame is not None:
             self._drop_frame.set_menu(None)
@@ -683,25 +710,13 @@ class DropSelect(Widget):
         if self.active and self.is_visible():
             self._check_drop_made()
 
-            if not self._open_middle:
-                self._drop_frame.draw(surface)
-                self.last_surface = surface
-
-            else:
-                new_surface = self._menu._widgets_surface
-
-                # Ignore draw if widget is within a frame, if so, the next call made by frame.draw()
-                # with surface=None is performed, but this time drop frame draws over "new_surface".
-                # If widget is not within a frame, this is not necessary as the frame is not drawn over
-                # and the widget is drawn at the end of all widgets
-                if surface == self.last_surface and self.get_frame() is not None:
-                    self.last_surface = new_surface
-                    return self
-
+            if self._open_middle:
                 # Draw drop frame in menu widgets surface
                 assert self._menu is not None, 'middle position need menu reference'
-                self._drop_frame.draw(new_surface)
-                self.last_surface = new_surface
+                surface = self._menu._widgets_surface
+
+            self._drop_frame.draw(surface)
+            self.last_surface = surface
 
         return self
 
@@ -755,10 +770,12 @@ class DropSelect(Widget):
 
         current_rect_bg = current.get_rect()
         current_rect_bg.x += title.get_width() + self._selection_box_margin[0]
-        current_rect_bg.y += (self._selection_box_inflate[1]) / 2 + vi + self._selection_box_margin[1]
+        current_rect_bg.y += int((self._selection_box_inflate[1]) / 2
+                                 + vi + self._selection_box_margin[1])
         current_rect_bg.width = self._selection_box_width
-        current_rect_bg = current_rect_bg.inflate((self._selection_box_inflate[0],
-                                                   self._selection_box_inflate[1] + 2 * vi))
+        current_rect_bg = current_rect_bg.inflate(
+            (int(self._selection_box_inflate[0]), int(self._selection_box_inflate[1] + 2 * vi))
+        )
 
         # Compute delta title if height is lower than selection box
         h = title.get_height()
@@ -766,18 +783,24 @@ class DropSelect(Widget):
 
         # Create arrows
         arrow = pygame.Rect(
-            title.get_width() + self._selection_box_margin[0] + self._selection_box_width - h,
-            self._selection_box_arrow_margin[2] + (self._selection_box_inflate[1] + vi / 2) / 2
-            + delta_title_height + self._selection_box_margin[1],
+            int(title.get_width()
+                + self._selection_box_margin[0]
+                + self._selection_box_width - h),
+            int(self._selection_box_arrow_margin[2]
+                + (self._selection_box_inflate[1] + vi / 2) / 2
+                + delta_title_height
+                + self._selection_box_margin[1]),
             h,
             h
         )
         w = h + self._selection_box_arrow_margin[1]
 
-        # Check which direction it should open
+        # Check which direction it should open (top, bottom)
         self._open_bottom = True
-        if self._drop_frame is not None and self._scrollarea is not None and \
-                not self._open_middle:
+        if self._drop_frame is not None and self._scrollarea is not None:
+            assert self.get_scrollarea().get_world() is not None, \
+                'scrollarea world is None. The widget have been appended to the ' \
+                'Menu?'
             rect = self._rect.copy()
             rect.width = self._selection_box_width
             rect.y += delta_title_height
@@ -787,6 +810,8 @@ class DropSelect(Widget):
                 rect_clipped = self._scrollarea.get_world_rect().clip(rect)
                 if rect.height != rect_clipped.height:
                     self._open_bottom = False
+
+        # Create frame
         if self._drop_frame is not None and self._open_middle and \
                 self._menu is not None:
             self._drop_frame.set_scrollarea(self._menu.get_scrollarea())
@@ -796,20 +821,20 @@ class DropSelect(Widget):
         else:
             self.force_menu_draw_focus = False
 
+        delta_title_height_dh = math.ceil((current_rect_bg.height - h) / 2) + \
+                                2 * self._selection_box_border_width
         if delta_title_height != 0:
-            self.set_attribute('delta_title_height',
-                               math.ceil((current_rect_bg.height - h) / 2)
-                               + 2 * self._selection_box_border_width)
+            self.set_attribute('delta_title_height', delta_title_height_dh)
 
         arrow_up = (
-            (arrow.right - w + h / 2 - h / 16, arrow.centery - h / 6 - h / 20),
-            (arrow.right - w + h / 2 + h / 4 - h / 16, arrow.centery + h / 4 - h / 20),
-            (arrow.right - w + h - h / 16, arrow.centery - h / 6 - h / 20)
+            (int(arrow.right - w + h / 2 - h / 16), int(arrow.centery - h / 6 - h / 20)),
+            (int(arrow.right - w + h / 2 + h / 4 - h / 16), int(arrow.centery + h / 4 - h / 20)),
+            (int(arrow.right - w + h - h / 16), int(arrow.centery - h / 6 - h / 20))
         )
         arrow_down = (
-            (arrow.right - w + h / 2 - h / 16, arrow.centery + h / 4 - h / 20),
-            (arrow.right - w + h / 2 + h / 4 - h / 16, arrow.centery - h / 6 - h / 20),
-            (arrow.right - w + h - h / 16, arrow.centery + h / 4 - h / 20)
+            (int(arrow.right - w + h / 2 - h / 16), int(arrow.centery + h / 4 - h / 20)),
+            (int(arrow.right - w + h / 2 + h / 4 - h / 16), int(arrow.centery - h / 6 - h / 20)),
+            (int(arrow.right - w + h - h / 16), int(arrow.centery + h / 4 - h / 20))
         )
         if not self._open_bottom:
             if not self.active:
@@ -822,12 +847,14 @@ class DropSelect(Widget):
             else:
                 arrow_right_pos = arrow_down
 
-        self._surface = make_surface(title.get_width() + self._selection_box_margin[0]
-                                     + self._selection_box_width + self._selection_box_inflate[0] / 2
+        self._surface = make_surface(title.get_width()
+                                     + self._selection_box_margin[0]
+                                     + self._selection_box_width
+                                     + self._selection_box_inflate[0] / 2
                                      + self._selection_box_border_width,
                                      max(title.get_height() + self._selection_box_inflate[1],
                                          current_rect_bg.height))
-        self._surface.blit(title, (0, self._selection_box_inflate[1] / 2 + delta_title_height))
+        self._surface.blit(title, (0, int(self._selection_box_inflate[1] / 2 + delta_title_height)))
         pygame.draw.rect(self._surface, self._selection_box_bgcolor, current_rect_bg)
         pygame.draw.rect(self._surface, self._selection_box_border_color, current_rect_bg,
                          self._selection_box_border_width)
@@ -845,10 +872,14 @@ class DropSelect(Widget):
         new_current.blit(current, (0, 0))
         # new_current.fill((0, 0, 0))
         self._surface.blit(new_current,
-                           (title.get_width() + self._selection_box_margin[0]
-                            + self._selection_box_text_margin,
-                            self._selection_box_inflate[1] / 2 + vi - 1
-                            + self._selection_box_margin[1]))
+                           (
+                               int(title.get_width()
+                                   + self._selection_box_margin[0]
+                                   + self._selection_box_text_margin),
+                               int(self._selection_box_inflate[1] / 2
+                                   + vi - 1
+                                   + self._selection_box_margin[1])
+                           ))
         if len(self._items) > 0:
             pygame.draw.polygon(self._surface, self._selection_box_arrow_color,
                                 arrow_right_pos)
@@ -932,7 +963,7 @@ class DropSelect(Widget):
         text if ``item`` is a string, or the index if ``item`` is an integer.
         This method raises ``ValueError`` if no item found.
 
-        For example, if widget item list is ``[['a',0],['b',1],['a',2]]``:
+        For example, if widget item list is ``[['a', 0], ['b', 1], ['a', 2]]``:
 
         - *widget*.set_value('a') -> Widget selects the first item (index 0)
         - *widget*.set_value(2) -> Widget selects the third item (index 2)
@@ -966,7 +997,9 @@ class DropSelect(Widget):
             btn = self._option_buttons[b_ind_x]
             if b_ind_x == self._index:
                 btn.set_background_color(self._selection_option_selected_bgcolor)
-                btn.update_font({'color': self._selection_option_font_style['color_selected']})
+                btn.update_font({
+                    'color': self._selection_option_font_style['color_selected']
+                })
                 if not self._drop_frame.has_attribute('ignorescroll'):
                     btn.scroll_to_widget(scroll_parent=False)
             else:
@@ -980,7 +1013,8 @@ class DropSelect(Widget):
         .. note::
 
             If the length of the list is different than the previous one, the new
-            index of the select will be the first item of the list.
+            index of the select will be the ``-1``, that is, same as the unselected
+            status.
 
         :param items: New drop select items; format ``[('Item1', a, b, c...), ('Item2', d, e, f...)]``
         :return: None
@@ -988,22 +1022,16 @@ class DropSelect(Widget):
         assert isinstance(items, list)
         if len(items) > 0:
             check_selector_items(items)
-        if self._index != -1:
-            selected_item = self._items[self._index]
-        else:
-            selected_item = None
-        self._items = items
-        if selected_item is not None:
-            try:
-                self._index = self._items.index(selected_item)
-            except ValueError:
-                if self._index >= len(self._items):
-                    self._index = -1
-                    self._default_value = -1
+        if self._index != -1 and len(items) != len(self._items) or \
+                (self._index + 1) > len(items):
+            self._index = -1
+            self._default_value = -1
+        self._items = items.copy()
         if self._drop_frame is not None:
             self._drop_frame.set_menu(None)
         self._drop_frame = None
         self.active = False
+        self._make_selection_drop()
 
     def _check_drop_made(self) -> None:
         """
@@ -1013,10 +1041,18 @@ class DropSelect(Widget):
         """
         if self._drop_frame is None:
             raise _SelectionDropNotMadeException(
-                'selection drop has not been made yet. Call {0}.make_selection_drop()'
+                'selection drop has not been made yet. Call {0}._make_selection_drop()'
                 'for avoiding this exception'.format(self.get_class_id())
             )
 
+    def get_items(self) -> Union[List[Tuple[Any, ...]], List[str]]:
+        """
+        Return a copy of the select items.
+
+        :return: Select items list
+        """
+        return self._items.copy()
+
     def _toggle_drop(self) -> None:
         """
         Open drop selection.
@@ -1079,13 +1115,23 @@ class DropSelect(Widget):
                           - self._drop_frame.get_attribute('extra_margin')
             if self._open_middle:
                 x, y = self._compute_position_middle(add_offset=False)
-                rect.x = x + self._menu.get_position()[0]
-                rect.y = y + self._menu.get_scrollarea().get_position()[1]
+                rect.x = int(x + self._menu.get_position()[0])
+                rect.y = int(y + self._menu.get_scrollarea().get_position()[1])
                 rect.height -= self._rect.height
         else:
             rect.width -= self._selection_box_border_width
         return rect
 
+    def _drop_frame_scrolling(self) -> bool:
+        """
+        Checks if drop frame is scrolling.
+
+        :return: ``True`` if scrolling
+        """
+        if self._drop_frame is None or self._drop_frame.get_scrollarea(inner=True) is None:
+            return False
+        return self._drop_frame.get_scrollarea(inner=True).is_scrolling()
+
     def update(self, events: EventVectorType) -> bool:
         self.apply_update_callbacks(events)
 
@@ -1121,7 +1167,7 @@ class DropSelect(Widget):
                 if not self.active:
                     continue
                 self._down()
-                updated = True
+                return True
 
             # Right button
             elif keydown and event.key == ctrl.KEY_MOVE_UP or \
@@ -1131,7 +1177,7 @@ class DropSelect(Widget):
                 if not self.active:
                     continue
                 self._up()
-                updated = True
+                return True
 
             # Press enter
             elif keydown and event.key == ctrl.KEY_APPLY or \
@@ -1141,47 +1187,43 @@ class DropSelect(Widget):
                     self.apply(*self._items[self._index][1:])
                 if not (self.active and (not self._close_on_apply and self._index != -1)):
                     self._toggle_drop()
-                updated = True
+                return True
 
             # Press keys which active the drop but not apply
             elif keydown and (event.key == pygame.K_TAB):
                 self._toggle_drop()
-                updated = True
+                return True
 
             # Close the selection
             elif keydown and (event.key == pygame.K_ESCAPE or
                               event.key == pygame.K_BACKSPACE):
                 if self.active:
                     self._toggle_drop()
-                updated = True
+                return True
 
             # Click on dropselect; don't consider the mouse wheel (button 4 & 5)
             elif self.active and (
                     event.type == pygame.MOUSEBUTTONDOWN and self._mouse_enabled and
-                    event.button in (1, 2, 3) or (
-                            event.type == FINGERDOWN and self._touchscreen_enabled and
-                            self._drop_frame is not None and
-                            not self._drop_frame.get_scrollarea(inner=True).is_scrolling() and
-                            self._menu is not None)
+                    event.button in (1, 2, 3) or
+                    event.type == FINGERDOWN and self._touchscreen_enabled and
+                    self._menu is not None and not self._drop_frame_scrolling()
             ):
                 event_pos = get_finger_pos(self._menu, event)
                 if self._drop_frame.get_rect(apply_padding=False, to_real_position=True
                                              ).collidepoint(*event_pos):
-                    updated = True
+                    return True
 
             # Click on dropselect; don't consider the mouse wheel (button 4 & 5)
             elif event.type == pygame.MOUSEBUTTONUP and self._mouse_enabled and \
                     event.button in (1, 2, 3) or \
                     event.type == FINGERUP and self._touchscreen_enabled and \
-                    self._menu is not None and \
-                    not (self._drop_frame is not None and
-                         self._drop_frame.get_scrollarea(inner=True).is_scrolling()):
+                    self._menu is not None and not self._drop_frame_scrolling():
 
                 # Check for mouse clicks within
                 if self.active:
                     for btn in self._option_buttons:
                         btn.set_attribute('ignore_scroll_to_widget')
-                        updated = btn.update(events)
+                        updated = btn.update([event])
                         try:
                             btn.remove_attribute('ignore_scroll_to_widget')
                         except IndexError:
@@ -1202,19 +1244,19 @@ class DropSelect(Widget):
                     dist = mouse_x - (topleft + self._title_size[0])  # Distance from title
                     if dist > 0:  # User clicked the options, not title
                         self._toggle_drop()
-                        updated = True
+                        return True
 
                 else:
                     if self.active and not self.get_focus_rect().collidepoint(*event_pos):
                         self._toggle_drop()
-                        updated = True
+                        return True
 
             # Check mousemove
             # elif event.type == pygame.MOUSEMOTION:
             #     for btn in self._option_buttons:
             #         btn._check_mouseover(event)
 
-        return updated
+        return False
 
 
 class _SelectionDropNotMadeException(Exception):
