@@ -29,18 +29,41 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-__all__ = ['DropSelectMultiple']
+__all__ = [
+
+    # Main Class
+    'DropSelectMultiple',
+
+    # Constants
+    'DROPSELECT_MULTIPLE_SFORMAT_LIST_COMMA',
+    'DROPSELECT_MULTIPLE_SFORMAT_LIST_HYPHEN',
+    'DROPSELECT_MULTIPLE_SFORMAT_TOTAL',
+
+    # Type
+    'DropSelectMultipleSFormatType'
+
+]
 
 import pygame
 
 from pygame_menu.font import FontType
-from pygame_menu.utils import assert_color, assert_vector
+from pygame_menu.locals import POSITION_NORTHWEST, POSITION_SOUTHEAST
+from pygame_menu.utils import assert_color, assert_vector, is_callable
 from pygame_menu.widgets.widget.button import Button
 from pygame_menu.widgets.widget.dropselect import DropSelect
 
 from pygame_menu._types import Tuple, Union, List, Any, Optional, CallbackType, \
     ColorType, ColorInputType, Tuple2IntType, Tuple3IntType, PaddingType, \
-    Tuple2NumberType, CursorInputType
+    Tuple2NumberType, CursorInputType, NumberType, Literal, Callable
+
+DROPSELECT_MULTIPLE_SFORMAT_LIST_COMMA = 'comma-list'
+DROPSELECT_MULTIPLE_SFORMAT_LIST_HYPHEN = 'hyphen-list'
+DROPSELECT_MULTIPLE_SFORMAT_TOTAL = 'total'
+
+DropSelectMultipleSFormatType = Union[Literal[DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
+                                              DROPSELECT_MULTIPLE_SFORMAT_LIST_COMMA,
+                                              DROPSELECT_MULTIPLE_SFORMAT_LIST_HYPHEN],
+                                      Callable[[List[str]], str]]
 
 
 # noinspection PyMissingOrEmptyDocstring
@@ -67,7 +90,7 @@ class DropSelectMultiple(DropSelect):
 
     .. note::
 
-        DropSelectMultiple only implements translation.
+        DropSelectMultiple accepts the same transformations as :py:class:`pygame_menu.widgets.DropSelect`.
 
     :param title: Drop select title
     :param items: Items of the drop select
@@ -80,7 +103,18 @@ class DropSelectMultiple(DropSelect):
     :param open_middle: If ``True`` the selection box is opened in the middle of the menu
     :param placeholder: Text shown if no option is selected yet
     :param placeholder_add_to_selection_box: If ``True`` adds the placeholder button to the selection box
-    :param placeholder_selected: Text shown if option is selected. Accepts the number of selected options
+    :param placeholder_selected: Text shown if option is selected. Accepts the formatted option from ``selection_placeholder_format``
+    :param scrollbar_color: Scrollbar color
+    :param scrollbar_cursor: Cursor of the scrollbars if mouse is placed over. By default is ``None``
+    :param scrollbar_shadow: Indicate if a shadow is drawn on each scrollbar
+    :param scrollbar_shadow_color: Color of the shadow of each scrollbar
+    :param scrollbar_shadow_offset: Offset of the scrollbar shadow in px
+    :param scrollbar_shadow_position: Position of the scrollbar shadow. See :py:mod:`pygame_menu.locals`
+    :param scrollbar_slider_color: Color of the sliders
+    :param scrollbar_slider_hover_color: Color of the slider if hovered or clicked
+    :param scrollbar_slider_pad: Space between slider and scrollbars borders in px
+    :param scrollbar_thick: Scrollbar thickness in px
+    :param scrollbars: Scrollbar position. See :py:mod:`pygame_menu.locals`
     :param selection_box_arrow_color: Selection box arrow color
     :param selection_box_arrow_margin: Selection box arrow margin (left, right, vertical) in px
     :param selection_box_bgcolor: Selection box background color
@@ -108,6 +142,7 @@ class DropSelectMultiple(DropSelect):
     :param selection_option_selected_box_height: Height of the selection box relative to the options height
     :param selection_option_selected_box_margin: Option box margin (left, right, vertical) in px
     :param selection_option_selected_font_color: Selected option(s) font color
+    :param selection_placeholder_format: Format of the string replaced in ``placeholder_selected``. Can be a predefined string type ("total", "comma-list", "hyphen-list", or any other string which will join the list) or a function that receives the list of selected items and returns a string
     :param kwargs: Optional keyword arguments
     """
     _max_selected: int
@@ -118,6 +153,7 @@ class DropSelectMultiple(DropSelect):
     _selection_option_selected_box: bool
     _selection_option_selected_box_color: ColorType
     _selection_option_selected_box_width: int
+    _selection_placeholder_format: DropSelectMultipleSFormatType
 
     def __init__(
             self,
@@ -133,6 +169,17 @@ class DropSelectMultiple(DropSelect):
             placeholder: str = 'Select an option',
             placeholder_add_to_selection_box: bool = True,
             placeholder_selected: str = '{0} selected',
+            scrollbar_color: ColorInputType = (235, 235, 235),
+            scrollbar_cursor: CursorInputType = None,
+            scrollbar_shadow: bool = False,
+            scrollbar_shadow_color: ColorInputType = (0, 0, 0),
+            scrollbar_shadow_offset: int = 2,
+            scrollbar_shadow_position: str = POSITION_NORTHWEST,
+            scrollbar_slider_color: ColorInputType = (200, 200, 200),
+            scrollbar_slider_hover_color: ColorInputType = (170, 170, 170),
+            scrollbar_slider_pad: NumberType = 0,
+            scrollbar_thick: int = 20,
+            scrollbars: str = POSITION_SOUTHEAST,
             selection_box_arrow_color: ColorInputType = (150, 150, 150),
             selection_box_arrow_margin: Tuple3IntType = (5, 5, 0),
             selection_box_bgcolor: ColorInputType = (255, 255, 255),
@@ -160,6 +207,7 @@ class DropSelectMultiple(DropSelect):
             selection_option_selected_box_height: float = 0.5,
             selection_option_selected_box_margin: Tuple3IntType = (0, 5, 0),
             selection_option_selected_font_color: ColorInputType = (0, 0, 0),
+            selection_placeholder_format: DropSelectMultipleSFormatType = DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
             *args,
             **kwargs
     ) -> None:
@@ -172,6 +220,17 @@ class DropSelectMultiple(DropSelect):
             open_middle=open_middle,
             placeholder=placeholder,
             placeholder_add_to_selection_box=placeholder_add_to_selection_box,
+            scrollbar_color=scrollbar_color,
+            scrollbar_cursor=scrollbar_cursor,
+            scrollbar_shadow=scrollbar_shadow,
+            scrollbar_shadow_color=scrollbar_shadow_color,
+            scrollbar_shadow_offset=scrollbar_shadow_offset,
+            scrollbar_shadow_position=scrollbar_shadow_position,
+            scrollbar_slider_color=scrollbar_slider_color,
+            scrollbar_slider_hover_color=scrollbar_slider_hover_color,
+            scrollbar_slider_pad=scrollbar_slider_pad,
+            scrollbar_thick=scrollbar_thick,
+            scrollbars=scrollbars,
             selection_box_arrow_color=selection_box_arrow_color,
             selection_box_arrow_margin=selection_box_arrow_margin,
             selection_box_bgcolor=selection_box_bgcolor,
@@ -222,6 +281,7 @@ class DropSelectMultiple(DropSelect):
         self._selection_option_selected_box = selection_option_selected_box
         self._selection_option_selected_box_color = assert_color(selection_option_selected_box_color)
         self._selection_option_selected_box_width = selection_option_selected_box_border
+        self._selection_placeholder_format = selection_placeholder_format
 
         self.set_default_value(default)
 
@@ -269,10 +329,48 @@ class DropSelectMultiple(DropSelect):
 
     def _get_current_selected_text(self) -> str:
         if len(self._selected_indices) == 0:
-            current_selected = self._placeholder
+            return self._placeholder
+
+        # Apply selected format
+        if self._selection_placeholder_format == DROPSELECT_MULTIPLE_SFORMAT_TOTAL:
+            return self._placeholder_selected.format(len(self._selected_indices))
+
+        list_items = self._get_selected_items_list_str()
+        if self._selection_placeholder_format == DROPSELECT_MULTIPLE_SFORMAT_LIST_COMMA:
+            return self._placeholder_selected.format(','.join(list_items))
+
+        elif self._selection_placeholder_format == DROPSELECT_MULTIPLE_SFORMAT_LIST_HYPHEN:
+            return self._placeholder_selected.format('-'.join(list_items))
+
+        elif isinstance(self._selection_placeholder_format, str):
+            return self._placeholder_selected.format(self._selection_placeholder_format.join(list_items))
+
+        elif is_callable(self._selection_placeholder_format):
+            try:
+                o = self._selection_placeholder_format(list_items)
+            except TypeError:
+                raise ValueError('selection placeholder function receives only 1 '
+                                 'argument (a list of the selected items string)'
+                                 ' and must return a string')
+            assert isinstance(o, str), \
+                'output from selection placeholder format function must be a ' \
+                'string (List[str]=>str), not {0} type ({1} returned)' \
+                ''.format(type(o), o)
+            return self._placeholder_selected.format(o)
+
         else:
-            current_selected = self._placeholder_selected.format(len(self._selected_indices))
-        return current_selected
+            raise ValueError('invalid selection placeholder format type')
+
+    def _get_selected_items_list_str(self) -> List[str]:
+        """
+        Return the selected items list of strings.
+
+        :return: List string of selected items
+        """
+        sel_items = []
+        for i in self._selected_indices:
+            sel_items.append(self._items[i][0])
+        return sel_items
 
     def get_value(self) -> Tuple[List[Union[Tuple[Any, ...], str]], List[int]]:
         selected_items = []
@@ -315,7 +413,8 @@ class DropSelectMultiple(DropSelect):
         .. note::
 
             If the length of the list is different than the previous one, the new
-            index of the select will be the first item of the list.
+            index of the select will be the ``-1``, that is, same as the unselected
+            status.
 
         :param items: New drop select items; format ``[('Item1', a, b, c...), ('Item2', d, e, f...)]``
         :return: None
@@ -354,7 +453,7 @@ class DropSelectMultiple(DropSelect):
         the text if ``item`` is a string, or the index if ``item`` is an integer.
         This method raises ``ValueError`` if no item found.
 
-        For example, if widget item list is ``[['a',0],['b',1],['a',2]]``:
+        For example, if widget item list is ``[['a', 0], ['b', 1], ['a', 2]]``:
 
         - *widget*.set_value('a') -> Widget selects the first item (index 0)
         - *widget*.set_value(2) -> Widget selects the third item (index 2)
@@ -380,7 +479,8 @@ class DropSelectMultiple(DropSelect):
                     found = True
                     break
             if not found:
-                raise ValueError('no value "{}" found in drop select multiple'.format(item))
+                raise ValueError('no value "{}" found in drop select multiple'
+                                 ''.format(item))
         elif isinstance(item, int):
             assert -1 <= item < len(self._items), \
                 'item index must be greater than zero and lower than the number ' \
@@ -420,8 +520,8 @@ class DropSelectMultiple(DropSelect):
                     deco.disable(btn.get_attribute('deco_on'))
                     deco.enable(btn.get_attribute('deco_off'))
 
-    def make_selection_drop(self, **kwargs) -> 'DropSelectMultiple':
-        super(DropSelectMultiple, self).make_selection_drop(**kwargs)
+    def _make_selection_drop(self) -> 'DropSelectMultiple':
+        super(DropSelectMultiple, self)._make_selection_drop()
         # Add button decorations
         for btn in self._option_buttons:
             deco = btn.get_decorator()
