@@ -56,7 +56,7 @@ from pygame_menu.locals import CURSOR_HAND, ORIENTATION_VERTICAL, ORIENTATION_HO
     FINGERMOTION
 from pygame_menu.font import FontType, assert_font
 from pygame_menu.utils import assert_alignment, make_surface, assert_vector, assert_orientation, \
-    assert_color, fill_gradient, parse_padding, uuid4, warn
+    assert_color, fill_gradient, parse_padding, uuid4, warn, get_finger_pos
 from pygame_menu.widgets.core.widget import Widget, check_widget_mouseleave
 from pygame_menu.widgets.widget.button import Button
 from pygame_menu.widgets.widget.label import Label
@@ -70,6 +70,7 @@ FRAME_DEFAULT_TITLE_BACKGROUND_COLOR = ((10, 36, 106), (166, 202, 240), False, T
 FRAME_TITLE_BUTTON_CLOSE = 'close'
 FRAME_TITLE_BUTTON_MAXIMIZE = 'maximize'
 FRAME_TITLE_BUTTON_MINIMIZE = 'minimize'
+S_FINGER_FACTOR = 0.25, 0.25
 
 # Types
 FrameTitleBackgroundColorType = Optional[Union[ColorInputType, ColorInputGradientType, BaseImage]]
@@ -93,10 +94,6 @@ class Frame(Widget):
     purpose use several frames. If widget width or height exceeds Frame size
     ``_FrameSizeException`` will be raised.
 
-    .. note::
-
-        Frame only implements translation and resize transformations.
-
     .. note::
 
         Frame cannot be selected. Thus, it does not receive any selection effect.
@@ -107,6 +104,10 @@ class Frame(Widget):
         be careful when removing. Check :py:class:`pygame_menu.widgets.DropSelect`
         as a complete example of Frame implementation within another Widgets.
 
+    .. note::
+
+        Frame only accepts translation and resize transformations.
+
     :param width: Frame width in px
     :param height: Frame height in px
     :param orientation: Frame orientation (horizontal or vertical). See :py:mod:`pygame_menu.locals`
@@ -135,6 +136,7 @@ class Frame(Widget):
     first_index: int  # First selectable widget index
     horizontal: bool
     last_index: int  # Last selectable widget index
+    selected_widget_draw: Tuple[Optional['Widget'], Optional['pygame.Surface']]  # Stores selected widget
 
     def __init__(
             self,
@@ -183,6 +185,7 @@ class Frame(Widget):
         self.is_scrollable = False
         self.is_selectable = False
         self.last_index = -1
+        self.selected_widget_draw = (None, None)
 
     def set_title(
             self,
@@ -360,10 +363,7 @@ class Frame(Widget):
         self.force_menu_surface_update()
 
         # Title adds frame to scrollable frames even if not scrollable
-        update_frames = self._get_menu_update_frames()
-        if self._menu is not None and (self not in update_frames):
-            update_frames.append(self)
-            self.sort_menu_update_frames()
+        self._append_menu_update_frame(self)
 
         return self._frame_title
 
@@ -379,9 +379,8 @@ class Frame(Widget):
         if self._has_title:
             self._frame_title = None
             self._has_title = False
-        update_frames = self._get_menu_update_frames()
-        if not self.is_scrollable and self in update_frames:
-            update_frames.remove(self)
+        if not self.is_scrollable:
+            self._remove_menu_update_frame(self)
         self._draggable = False
         self._render()
         self.force_menu_surface_update()
@@ -517,6 +516,7 @@ class Frame(Widget):
                 (btn_rect.left + t, btn_rect.top + t)
             )
             border = 0
+
         elif style == FRAME_TITLE_BUTTON_MAXIMIZE:
             style_pos = (
                 (btn_rect.left + t, btn_rect.bottom - t),
@@ -524,11 +524,13 @@ class Frame(Widget):
                 (btn_rect.right - t, btn_rect.top + t),
                 (btn_rect.left + t, btn_rect.top + t)
             )
+
         elif style == FRAME_TITLE_BUTTON_MINIMIZE:
             style_pos = (
                 (btn_rect.left + t, btn_rect.centery + border),
                 (btn_rect.right - t, btn_rect.centery + border)
             )
+
         else:
             raise ValueError('unknown button style "{0}"'.format(style))
 
@@ -555,7 +557,21 @@ class Frame(Widget):
         """
         return self._width, self._height
 
-    def sort_menu_update_frames(self) -> None:
+    def _get_menu_update_frames(self) -> List['pygame_menu.widgets.Frame']:
+        """
+        Return the menu update frames list.
+
+        .. warning::
+
+            Use with caution.
+
+        :return: Frame update list if the menu reference is not ``None``, else, return an empty list
+        """
+        if self._menu is not None:
+            return self._menu._update_frames
+        return []
+
+    def _sort_menu_update_frames(self) -> None:
         """
         Sort the menu update frames (frames which receive updates).
 
@@ -564,6 +580,31 @@ class Frame(Widget):
         if self._menu is not None:
             self._menu._sort_update_frames()
 
+    def _append_menu_update_frame(self, frame: 'Frame') -> None:
+        """
+        Append update frame to menu and sort.
+
+        :param frame: Frame to append
+        :return: None
+        """
+        assert isinstance(frame, Frame)
+        update_frames = self._get_menu_update_frames()
+        if frame not in update_frames:
+            update_frames.append(frame)
+            self._sort_menu_update_frames()
+
+    def _remove_menu_update_frame(self, frame: 'Frame') -> None:
+        """
+        Remove update frame to menu and sort.
+
+        :param frame: Frame to append
+        :return: None
+        """
+        assert isinstance(frame, Frame)
+        update_frames = self._get_menu_update_frames()
+        if frame in update_frames:
+            update_frames.remove(frame)
+
     def on_remove_from_menu(self) -> 'Frame':
         for w in self.get_widgets(unpack_subframes=False):
             self.unpack(w)
@@ -572,18 +613,14 @@ class Frame(Widget):
 
     def set_menu(self, menu: Optional['pygame_menu.Menu']) -> 'Frame':
         # If menu is set, remove from previous scrollable if enabled
-        prev_update_frames = self._get_menu_update_frames()
-        if self in prev_update_frames:
-            prev_update_frames.remove(self)
+        self._remove_menu_update_frame(self)
 
         # Update menu
         super(Frame, self).set_menu(menu)
 
         # Add self to scrollable
-        new_update_frames = self._get_menu_update_frames()
-        if self.is_scrollable and self._menu is not None:
-            new_update_frames.append(self)
-            self.sort_menu_update_frames()
+        if self.is_scrollable:
+            self._append_menu_update_frame(self)
 
         return self
 
@@ -600,7 +637,7 @@ class Frame(Widget):
 
     def get_max_size(self) -> Tuple2IntType:
         """
-        Returns the max size of the frame.
+        Return the max size of the frame.
 
         :return: Max (width, height) in px
         """
@@ -678,9 +715,8 @@ class Frame(Widget):
             self._frame_scrollarea = None
 
             # If in previous scrollable frames
-            update_frames = self._get_menu_update_frames()
-            if self.is_scrollable and self in update_frames:
-                update_frames.remove(self)
+            if self.is_scrollable:
+                self._remove_menu_update_frame(self)
 
             self.is_scrollable = False
             return self
@@ -690,6 +726,10 @@ class Frame(Widget):
             area_color=scrollarea_color,
             area_height=max_height + sx,
             area_width=max_width + sy,
+            controls_joystick=self._joystick_enabled,
+            controls_keyboard=self._keyboard_enabled,
+            controls_mouse=self._mouse_enabled,
+            controls_touchscreen=self._touchscreen_enabled,
             parent_scrollarea=self._scrollarea,
             scrollbar_color=scrollbar_color,
             scrollbar_cursor=scrollbar_cursor,
@@ -737,6 +777,9 @@ class Frame(Widget):
         # Configure size
         self._frame_size = (max_width + sy, max_height + sx)
 
+        # Set menu
+        self._frame_scrollarea.set_menu(self._menu)
+
         # If has title
         if self._has_title:
             warn('previous {0} title has been removed'.format(self.get_class_id()))
@@ -846,7 +889,7 @@ class Frame(Widget):
         if not self.is_visible():
             return self
 
-        selected_widget = None
+        selected_widget: Optional['Widget'] = None
 
         # Simple case, no scrollarea
         if not self.is_scrollable:
@@ -857,8 +900,6 @@ class Frame(Widget):
                 if widget.is_selected():
                     selected_widget = widget
                 widget.draw(surface)
-            if selected_widget is not None:
-                selected_widget.draw_after_if_selected(surface)
             self._draw_border(surface)
             self._decorator.draw_post(surface)
 
@@ -874,12 +915,7 @@ class Frame(Widget):
                 if widget.is_selected():
                     selected_widget = widget
                 widget.draw(self._surface)
-            if selected_widget is not None:
-                selected_widget.draw_after_if_selected(self._surface)
             self._frame_scrollarea.draw(surface)
-            if selected_widget is not None and \
-                    selected_widget.last_surface != self._surface:  # Draw after was not completed
-                selected_widget.draw_after_if_selected(None)
             self._draw_border(surface)
 
         # If title
@@ -888,6 +924,9 @@ class Frame(Widget):
 
         self.apply_draw_callbacks()
 
+        # Stores selected widget
+        self.selected_widget_draw = selected_widget, self.last_surface
+
         return self
 
     def _get_ht(self, widget: 'Widget', a: str) -> int:
@@ -966,7 +1005,8 @@ class Frame(Widget):
             dw = x_left - x_right
             if dw > self._width and not self._relax:
                 raise _FrameSizeException(
-                    '{3} width ({0}) exceeds {2} width ({1})'
+                    '{3} width ({0}) exceeds {2} width ({1}). Set frame._relax=True'
+                    ' to ignore this Exception'
                     ''.format(dw, self._width, self.get_class_id(), w.get_class_id())
                 )
 
@@ -975,7 +1015,8 @@ class Frame(Widget):
         if w_center > available and not self._relax:
             raise _FrameSizeException(
                 'cannot place center widgets as required width ({0}) is greater '
-                'than available ({1}) in {2}'
+                'than available ({1}) in {2}. Set frame._relax=True to ignore '
+                'this Exception'
                 ''.format(w_center, available, self.get_class_id())
             )
         x_center = int(self._width / 2 - w_center / 2)
@@ -1016,7 +1057,8 @@ class Frame(Widget):
             dh = y_top - y_bottom
             if dh > self._height and not self._relax:
                 raise _FrameSizeException(
-                    '{3} height ({0}) exceeds {2} height ({1})'
+                    '{3} height ({0}) exceeds {2} height ({1}). Set frame._relax=True'
+                    ' to ignore this Exception'
                     ''.format(dh, self._height, self.get_class_id(), w.get_class_id())
                 )
 
@@ -1025,7 +1067,8 @@ class Frame(Widget):
         if w_center > available and not self._relax:
             raise _FrameSizeException(
                 'cannot place center widgets as required height ({0}) is greater '
-                'than available ({1}) in {2}'
+                'than available ({1}) in {2}. Set frame._relax=True to ignore '
+                'this Exception'
                 ''.format(w_center, available, self.get_class_id())
             )
         y_center = int(self._height / 2 - w_center / 2)
@@ -1411,7 +1454,7 @@ class Frame(Widget):
             self.scrollh(0)
 
         if isinstance(widget, Frame):
-            self.sort_menu_update_frames()
+            self._sort_menu_update_frames()
 
         # Update widget leave
         check_widget_mouseleave()
@@ -1539,7 +1582,7 @@ class Frame(Widget):
         else:
             widget.set_scrollarea(self._scrollarea)
         if self.is_scrollable or self._has_title or isinstance(widget, Frame):
-            self.sort_menu_update_frames()
+            self._sort_menu_update_frames()
         self._widgets[widget.get_id()] = widget
         self._widgets_props[widget.get_id()] = (align, vertical_position)
 
@@ -1631,7 +1674,7 @@ class Frame(Widget):
 
     def contains_widget(self, widget: 'Widget') -> bool:
         """
-        Returns true if the frame contains the given widget.
+        Return true if the frame contains the given widget.
 
         :param widget: Widget to check
         :return: ``True`` if widget within frame
@@ -1711,10 +1754,12 @@ class Frame(Widget):
                 self._frame_title._check_mouseover(event)
 
                 # If clicked in title
-                if (event.type == pygame.MOUSEBUTTONDOWN and self._mouse_enabled and event.button in (
-                        1, 2, 3) or event.type == FINGERDOWN and self._touchscreen_enabled) and \
+                if (event.type == pygame.MOUSEBUTTONDOWN and self._mouse_enabled and event.button in
+                    (1, 2, 3) or event.type == FINGERDOWN and self._touchscreen_enabled and self._menu is not None) and \
                         self._draggable:
-                    if self._frame_title.get_rect(to_real_position=True).collidepoint(*event.pos):
+                    event_pos = get_finger_pos(self._menu, event)
+
+                    if self._frame_title.get_rect(to_real_position=True).collidepoint(*event_pos):
                         if not self._frame_title.get_attribute('drag', False):
                             self._frame_title.set_attribute('drag', True)
                             updated = True
@@ -1733,26 +1778,31 @@ class Frame(Widget):
 
                 # User moves the mouse while drag
                 elif event.type == pygame.MOUSEMOTION and hasattr(event, 'rel') or \
-                        event.type == FINGERMOTION and self._touchscreen_enabled:
+                        event.type == FINGERMOTION and self._touchscreen_enabled and self._menu is not None:
+
                     if self._frame_title.get_attribute('drag', False) and self._draggable:
                         # Get relative movement
-                        rx = event.rel[0]
-                        ry = event.rel[1]
+                        rx = event.rel[0] if event.type == pygame.MOUSEMOTION else \
+                            event.dx * self._menu.get_window_size()[0] * S_FINGER_FACTOR[0]
+                        ry = event.rel[1] if event.type == pygame.MOUSEMOTION else \
+                            event.dy * self._menu.get_window_size()[1] * S_FINGER_FACTOR[1]
 
+                        event_pos = get_finger_pos(self._menu, event)
                         tx, ty = self.get_translate()
                         title_rect = self._frame_title.get_rect(to_real_position=True)
 
                         if self._rect.y <= 0:
-                            if not title_rect.collidepoint(*event.pos):
+                            if not title_rect.collidepoint(*event_pos):
                                 if ry > 0:
                                     self.translate(tx, ty - self._rect.y)
                                     self.force_menu_surface_update()
                                     updated = True
                                 continue
+
                         elif self.get_scrollarea() is not None:
                             max_v = self.get_scrollarea().get_world_size()[1] - self._title_height()
                             if self._rect.y >= max_v:
-                                if not title_rect.collidepoint(*event.pos):
+                                if not title_rect.collidepoint(*event_pos):
                                     if ry < 0:
                                         continue
                                 if ry > 0:
