@@ -47,6 +47,10 @@ class Label(Widget):
     """
     Label widget.
 
+    .. note::
+
+        Label accepts all transformations.
+
     :param title: Label title/text
     :param label_id: Label ID
     :param onselect: Function when selecting the label widget
@@ -133,7 +137,6 @@ class Label(Widget):
             menu_update_widgets.remove(self)
         if generator is not None and self not in menu_update_widgets:
             menu_update_widgets.append(self)
-
         return self
 
     def set_title(self, title: str) -> 'Label':
