@@ -105,6 +105,10 @@ class Selector(Widget):
 
     For example, if ``selected_index=0`` then ``selected_item=('Item1', a, b, c...)``.
 
+    .. note::
+
+        Selector accepts all transformations.
+
     :param title: Selector title
     :param items: Items of the selector
     :param selector_id: ID of the selector
@@ -191,6 +195,7 @@ class Selector(Widget):
             kwargs=kwargs
         )
 
+        self._accept_events = True
         self._index = 0
         self._items = items.copy()
         self._sformat = ''
@@ -267,9 +272,10 @@ class Selector(Widget):
 
             # Create arrows
             arrow_left = pygame.Rect(
-                title.get_width() + self._style_fancy_arrow_margin[0]
-                + self._style_fancy_box_margin[0],
-                self._style_fancy_arrow_margin[2] + self._style_fancy_box_inflate[1] / 2,
+                int(title.get_width() + self._style_fancy_arrow_margin[0]
+                    + self._style_fancy_box_margin[0]),
+                int(self._style_fancy_arrow_margin[2]
+                    + self._style_fancy_box_inflate[1] / 2),
                 title.get_height(),
                 title.get_height()
             )
@@ -285,11 +291,14 @@ class Selector(Widget):
             )
 
             arrow_right = pygame.Rect(
-                title.get_width() + 2 * self._style_fancy_arrow_margin[0]
-                + self._style_fancy_box_margin[0]
-                + self._style_fancy_arrow_margin[1] + current.get_width(),
-                self._style_fancy_arrow_margin[2] + self._style_fancy_box_inflate[1] / 2
-                + self._style_fancy_box_margin[1],
+                int(title.get_width()
+                    + 2 * self._style_fancy_arrow_margin[0]
+                    + self._style_fancy_box_margin[0]
+                    + self._style_fancy_arrow_margin[1] + current.get_width()
+                    ),
+                int(self._style_fancy_arrow_margin[2]
+                    + self._style_fancy_box_inflate[1] / 2
+                    + self._style_fancy_box_margin[1]),
                 title.get_height(),
                 title.get_height()
             )
@@ -314,11 +323,11 @@ class Selector(Widget):
                 + self._style_fancy_borderwidth
                 + self._style_fancy_box_inflate[0] / 2,
                 title.get_height() + self._style_fancy_box_inflate[1])
-            self._surface.blit(title, (0, self._style_fancy_box_inflate[1] / 2))
+            self._surface.blit(title, (0, int(self._style_fancy_box_inflate[1] / 2)))
             current_rect_bg = current.get_rect()
             current_rect_bg.x += title.get_width() + self._style_fancy_box_margin[0]
-            current_rect_bg.y += self._style_fancy_box_inflate[1] / 2 \
-                                 + self._style_fancy_box_margin[1]
+            current_rect_bg.y += int(self._style_fancy_box_inflate[1] / 2
+                                     + self._style_fancy_box_margin[1])
             current_rect_bg.width += 2 * (self._style_fancy_arrow_margin[0]
                                           + self._style_fancy_arrow_margin[1]
                                           + arrow_left.width)
@@ -327,13 +336,13 @@ class Selector(Widget):
             pygame.draw.rect(self._surface, self._style_fancy_bordercolor, current_rect_bg,
                              self._style_fancy_borderwidth)
             self._surface.blit(
-                current, (title.get_width()
-                          + arrow_left.width
-                          + self._style_fancy_arrow_margin[0]
-                          + self._style_fancy_arrow_margin[1]
-                          + self._style_fancy_box_margin[0],
-                          self._style_fancy_box_inflate[1] / 2
-                          + self._style_fancy_box_margin[1]))
+                current, (int(title.get_width()
+                              + arrow_left.width
+                              + self._style_fancy_arrow_margin[0]
+                              + self._style_fancy_arrow_margin[1]
+                              + self._style_fancy_box_margin[0]),
+                          int(self._style_fancy_box_inflate[1] / 2
+                              + self._style_fancy_box_margin[1])))
             pygame.draw.polygon(self._surface, self._style_fancy_arrow_color, arrow_left_pos)
             pygame.draw.polygon(self._surface, self._style_fancy_arrow_color, arrow_right_pos)
 
@@ -349,6 +358,14 @@ class Selector(Widget):
         """
         return self._index
 
+    def get_items(self) -> Union[List[Tuple[Any, ...]], List[str]]:
+        """
+        Return a copy of the select items.
+
+        :return: Select items list
+        """
+        return self._items.copy()
+
     def get_value(self) -> Tuple[Union[Tuple[Any, ...], str], int]:
         """
         Return the current value of the selected index.
@@ -387,7 +404,7 @@ class Selector(Widget):
         the text if ``item`` is a string, or the index if ``item`` is an integer.
         This method raises ``ValueError`` if no item found.
 
-        For example, if widget item list is ``[['a',0],['b',1],['a',2]]``:
+        For example, if widget item list is ``[['a', 0], ['b', 1], ['a', 2]]``:
 
         - *widget*.set_value('a') -> Widget selects the first item (index 0)
         - *widget*.set_value(2) -> Widget selects the third item (index 2)
@@ -442,7 +459,6 @@ class Selector(Widget):
 
         if self.readonly or not self.is_visible():
             return False
-        updated = False
 
         for event in events:
 
@@ -464,21 +480,21 @@ class Selector(Widget):
                     joy_hatmotion and event.value == ctrl.JOY_LEFT or \
                     joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value < ctrl.JOY_DEADZONE:
                 self._left()
-                updated = True
+                return True
 
             # Right button
             elif keydown and event.key == ctrl.KEY_RIGHT or \
                     joy_hatmotion and event.value == ctrl.JOY_RIGHT or \
                     joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value > -ctrl.JOY_DEADZONE:
                 self._right()
-                updated = True
+                return True
 
             # Press enter
             elif keydown and event.key == ctrl.KEY_APPLY or \
                     joy_button_down and event.button == ctrl.JOY_BUTTON_SELECT:
                 self._sound.play_key_add()
                 self.apply(*self._items[self._index][1:])
-                updated = True
+                return True
 
             # Click on selector; don't consider the mouse wheel (button 4 & 5)
             elif event.type == pygame.MOUSEBUTTONUP and self._mouse_enabled and \
@@ -503,6 +519,6 @@ class Selector(Widget):
                             self._left()
                         else:
                             self._right()
-                        updated = True
+                        return True
 
-        return updated
+        return False
