@@ -39,7 +39,8 @@ from pygame_menu.locals import ORIENTATION_VERTICAL, ALIGN_LEFT, ALIGN_CENTER, \
     ORIENTATION_HORIZONTAL, POSITION_NORTH, POSITION_CENTER, POSITION_SOUTH, \
     ALIGN_RIGHT, POSITION_WEST, POSITION_EAST
 from pygame_menu.utils import assert_alignment, assert_color, uuid4, parse_padding, \
-    assert_position, assert_vector
+    assert_position, assert_vector, warn
+from pygame_menu.version import ver
 from pygame_menu.widgets.core.widget import Widget, WidgetBorderPositionType, \
     WIDGET_FULL_BORDER, WIDGET_BORDER_POSITION_NONE
 from pygame_menu.widgets.widget.frame import Frame
@@ -48,7 +49,7 @@ from pygame_menu.widgets.widget.label import Label
 from pygame_menu.widgets.widget.surface import SurfaceWidget
 
 from pygame_menu._types import List, Union, ColorInputType, Optional, Tuple, \
-    VectorInstance, PaddingType, Dict, NumberType, Vector2IntType
+    VectorInstance, PaddingType, Dict, NumberType, Vector2IntType, EventVectorType
 
 CellType = Union['Widget', str, int, float, bool, 'BaseImage', 'pygame.Surface']
 ColumnInputType = Union[Tuple[CellType, ...], List[CellType]]
@@ -61,15 +62,16 @@ class Table(Frame):
 
     .. note::
 
-        Table only implements translation transformation.
+        Table cannot be selected. Thus, it does not receive any selection effect.
 
     .. note::
 
-        Table cannot be selected. Thus, it does not receive any selection effect.
+        Table only accepts translation and resize transformations.
 
     :param table_id: ID of the table
     """
     _rows: List['Frame']
+    _update_widgets: List['Widget']
     default_cell_align: str
     default_cell_border_color: ColorInputType
     default_cell_border_position: WidgetBorderPositionType
@@ -91,6 +93,7 @@ class Table(Frame):
 
         # Internals
         self._rows = []
+        self._update_widgets = []
 
         # Frame behaviour
         self._accepts_scrollarea = False
@@ -143,6 +146,7 @@ class Table(Frame):
         self._rows.remove(row)
         self._menu_render()
         self._update_row_sizing()
+        self._update_event_widgets()
 
         # Remove scrollable from rows
         if self._menu is not None:
@@ -154,7 +158,7 @@ class Table(Frame):
                         menu_update_frames.remove(w)
                         total_removed += 1
             if total_removed > 0:
-                self.sort_menu_update_frames()
+                self._sort_menu_update_frames()
 
     @staticmethod
     def _check_cell_style(
@@ -235,6 +239,13 @@ class Table(Frame):
 
             By default, the cell font is the same as the table font style.
 
+        .. warning::
+
+            Currently, only static widgets work properly, that is, widgets that
+            does not accept events. Buttons or TextInputs can be added, but them
+            will not accept any event, also, these widgets cannot be selected.
+            That's because the Table architecture relies on Frame widget.
+
         :param cells: Cells to add. This can be a tuple or list of widgets, string, numbers, boolean values or images. Also a Frame row can be added
         :param cell_align: Horizontal align of each cell. See :py:mod:`pygame_menu.locals`
         :param cell_border_color: Border color of each cell
@@ -318,13 +329,22 @@ class Table(Frame):
         row.set_menu(self._menu)
         row.set_scrollarea(self._scrollarea)
         row.set_attribute('is_row')
+        row.set_controls(
+            joystick=self._joystick_enabled,
+            mouse=self._mouse_enabled,
+            touchscreen=self._touchscreen_enabled,
+            keyboard=self._keyboard_enabled
+        )
         # row.set_frame(self) This cannot be executed as row is packed within
 
         # Create widgets
         row_cells: List['Widget'] = []
         cell: 'Widget'
         j = 0
+
         for c in cells:
+            cell_widget_type = False
+
             if isinstance(c, (str, int, float, bool)):
                 cell = Label(c, label_id=self._id + '+cell-label-' + uuid4(short=True))
                 cell.set_font(
@@ -339,19 +359,43 @@ class Table(Frame):
                 )
                 cell.set_padding(0)
                 cell.set_tab_size(self._tab_size)
+
             elif isinstance(c, BaseImage):
                 cell = Image(
                     c, image_id=self._id + '+cell-image-' + uuid4(short=True)
                 )
+
             elif isinstance(c, pygame.Surface):
                 cell = SurfaceWidget(
                     c, surface_id=self._id + '+cell-surface-' + uuid4(short=True)
                 )
+
             else:
                 assert isinstance(c, Widget)
+                assert c != self, '{0} cannot be appended to itself'.format(self.get_class_id())
+
+                # Check if Frame not recursive
+                if isinstance(c, Frame):
+                    print(self, c.get_widgets())
+                    assert self not in c.get_widgets(unpack_subframes_include_frame=True), \
+                        '{0} cannot be packed within {1}, recursive packing is ' \
+                        'not allowed (Table is within Frame to be inserted as ' \
+                        'row cell)' \
+                        ''.format(self.get_class_id(), c.get_class_id())
+
                 cell = c
+                if c._accept_events:
+                    cell_widget_type = True
+                    warn('{0} does not accept events in current pygame-menu '
+                         'v{1}; thus appended cell row widget {2} (pos {3}) would'
+                         ' not work properly, as it will ignore all inputs. Also, '
+                         'widgets within Tables cannot be selected. Consider Tables'
+                         'as visual-only'
+                         .format(self.get_class_id(), ver, c.get_class_id(), j))
+                # self._append_menu_update_frame(self)
 
             # Configure cell
+            cell.set_attribute('accept_events', cell_widget_type)
             cell.set_attribute('align', cell_align)
             cell.set_attribute('background_color', row_background_color)
             cell.set_attribute('border_color', cell_border_color)
@@ -384,11 +428,8 @@ class Table(Frame):
                           self.get_class_id())
 
             # If cell is frame and scrollable
-            if isinstance(cell, Frame) and self._menu is not None:
-                menu_update_frames = self._get_menu_update_frames()
-                if cell not in menu_update_frames:
-                    menu_update_frames.append(cell)
-                    self.sort_menu_update_frames()
+            if isinstance(cell, Frame):
+                self._append_menu_update_frame(cell)
 
             # Add to cells
             row_cells.append(cell)
@@ -404,9 +445,22 @@ class Table(Frame):
 
         # Update size
         self._update_row_sizing()
+        self._update_event_widgets()
 
         return row
 
+    def _update_event_widgets(self) -> None:
+        """
+        Update the list of widgets that accept events.
+
+        :return: None
+        """
+        self._update_widgets = []
+        for r in self._rows:
+            for w in r.get_widgets():
+                if w.get_attribute('accept_events'):
+                    self._update_widgets.append(w)
+
     def _get_column_width_row_height(self) -> Tuple[Dict[int, int], Dict['Frame', int]]:
         """
         Return column width and row height.
@@ -624,7 +678,7 @@ class Table(Frame):
 
     def is_rectangular(self) -> bool:
         """
-        Returns ``True`` if the table is rectangular, that is, each row have the
+        Return ``True`` if the table is rectangular, that is, each row have the
         same number of columns.
 
         :return: Bool
@@ -856,3 +910,15 @@ class Table(Frame):
             return self
         super(Table, self).draw(surface)
         self._draw_cell_borders(self.last_surface)
+
+    def update(self, events: EventVectorType) -> bool:
+        super(Table, self).update(events)
+        updated = False
+
+        # if self.readonly or not self.is_visible():
+        #     return updated
+        #
+        # for w in self._update_widgets:
+        #     updated = w.update(events) or updated
+
+        return updated
