@@ -53,7 +53,7 @@ class ToggleSwitch(Widget):
 
     If the state of the widget changes the ``onchange`` callback is called. The
     state can change by pressing LEFT/RIGHT or RETURN if the widget only has two
-    states. This class can handle more than 2 states.
+    states. This widget can handle more than 2 states.
 
     .. code-block:: python
 
@@ -61,7 +61,7 @@ class ToggleSwitch(Widget):
 
     .. note::
 
-        This widget only accepts translation transformation.
+        ToggleSwitch only accepts translation transformation.
 
     :param title: Toggle switch title
     :param toggleswitch_id: ToggleSwitch ID
@@ -259,6 +259,7 @@ class ToggleSwitch(Widget):
             self._state_width_accum.append(accum_width)
 
         # Inner properties
+        self._accept_events = True
         self._slider_height = 0
         self._slider_pos = (0, 0)  # to add to (rect.x, rect.y)
         self._state_font = None
@@ -339,10 +340,10 @@ class ToggleSwitch(Widget):
         if self._state_text[self._state] != '':
             text = self._switch_font_rendered[self._state]
             surface.blit(text, (
-                switch_x
-                + (self._switch_width - text.get_width()) * self._state_text_position[0],
-                switch_y
-                + (self._switch_height - text.get_height()) * self._state_text_position[1]
+                int(switch_x
+                    + (self._switch_width - text.get_width()) * self._state_text_position[0]),
+                int(switch_y
+                    + (self._switch_height - text.get_height()) * self._state_text_position[1])
             ))
 
         # Draw slider
@@ -419,7 +420,6 @@ class ToggleSwitch(Widget):
 
         if self.readonly or not self.is_visible():
             return False
-        updated = False
 
         for event in events:
 
@@ -440,14 +440,14 @@ class ToggleSwitch(Widget):
                     joy_hatmotion and event.value == ctrl.JOY_LEFT or \
                     joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value < ctrl.JOY_DEADZONE:
                 self._left()
-                updated = True
+                return True
 
             # Right button
             elif keydown and event.key == ctrl.KEY_RIGHT or \
                     joy_hatmotion and event.value == ctrl.JOY_RIGHT or \
                     joy_axismotion and event.axis == ctrl.JOY_AXIS_X and event.value > -ctrl.JOY_DEADZONE:
                 self._right()
-                updated = True
+                return True
 
             # Press enter
             elif keydown and event.key == ctrl.KEY_APPLY and self._total_states == 2 or \
@@ -456,8 +456,8 @@ class ToggleSwitch(Widget):
                 self._sound.play_key_add()
                 self._state = int(not self._state)
                 self.change()
-                updated = True
                 self.active = not self.active
+                return True
 
             # Click on switch; don't consider the mouse wheel (button 4 & 5)
             elif event.type == pygame.MOUSEBUTTONUP and self._mouse_enabled and \
@@ -484,7 +484,7 @@ class ToggleSwitch(Widget):
                                 self._left()
                             else:
                                 self._right()
-                            updated = True
+                            return True
 
                         else:
                             target_index = 0
@@ -499,6 +499,6 @@ class ToggleSwitch(Widget):
                                 self._sound.play_key_add()
                                 self._state = target_index
                                 self.change()
-                                updated = True
+                                return True
 
-        return updated
+        return False
